import sys
import ctypes
class DataAdapterSPIMode:
	# CPOL = 0 CPHA = 0
	SPI_MODE_0 = 1
	# CPOL = 0 CPHA = 1
	SPI_MODE_1 = 2
	# CPOL = 1 CPHA = 0
	SPI_MODE_2 = 3
	# CPOL = 1 CPHA = 1
	SPI_MODE_3 = 4

	@classmethod
	def getName(self, val):
		if val == self.SPI_MODE_0:
			return "SPI_MODE_0"
		if val == self.SPI_MODE_1:
			return "SPI_MODE_1"
		if val == self.SPI_MODE_2:
			return "SPI_MODE_2"
		if val == self.SPI_MODE_3:
			return "SPI_MODE_3"
		return "<invalid enumeration value>"



import sys
import ctypes
class SpatialAlgorithm:
	# No AHRS algorithm is used.
	SPATIAL_ALGORITHM_NONE = 0
	# AHRS algorithm, incorporating magnetometer data for yaw correction.
	SPATIAL_ALGORITHM_AHRS = 1
	# IMU algorithm, using gyro and accelerometer, but not magnetometer.
	SPATIAL_ALGORITHM_IMU = 2

	@classmethod
	def getName(self, val):
		if val == self.SPATIAL_ALGORITHM_NONE:
			return "SPATIAL_ALGORITHM_NONE"
		if val == self.SPATIAL_ALGORITHM_AHRS:
			return "SPATIAL_ALGORITHM_AHRS"
		if val == self.SPATIAL_ALGORITHM_IMU:
			return "SPATIAL_ALGORITHM_IMU"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.SpatialAlgorithm import SpatialAlgorithm
from Phidget22.SpatialEulerAngles import SpatialEulerAngles
from Phidget22.SpatialQuaternion import SpatialQuaternion
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class Spatial(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._AlgorithmDataFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		else:
			self._AlgorithmDataFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		self._AlgorithmData = None
		self._onAlgorithmData = None

		if sys.platform == 'win32':
			self._SpatialDataFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.POINTER(ctypes.c_double), ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		else:
			self._SpatialDataFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.POINTER(ctypes.c_double), ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		self._SpatialData = None
		self._onSpatialData = None

		__func = PhidgetSupport.getDll().PhidgetSpatial_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localAlgorithmDataEvent(self, handle, userPtr, quaternion, timestamp):
		if self._AlgorithmData == None:
			return
		quaternion = [quaternion[i] for i in range(4)]
		self._AlgorithmData(self, quaternion, timestamp)

	def setOnAlgorithmDataHandler(self, handler):
		if handler == None:
			self._AlgorithmData = None
			self._onAlgorithmData = None
		else:
			self._AlgorithmData = handler
			self._onAlgorithmData = self._AlgorithmDataFactory(self._localAlgorithmDataEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetSpatial_setOnAlgorithmDataHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onAlgorithmData, None)
		except RuntimeError:
			self._AlgorithmData = None
			self._onAlgorithmData = None

	def _localSpatialDataEvent(self, handle, userPtr, acceleration, angularRate, magneticField, timestamp):
		if self._SpatialData == None:
			return
		acceleration = [acceleration[i] for i in range(3)]
		angularRate = [angularRate[i] for i in range(3)]
		magneticField = [magneticField[i] for i in range(3)]
		self._SpatialData(self, acceleration, angularRate, magneticField, timestamp)

	def setOnSpatialDataHandler(self, handler):
		if handler == None:
			self._SpatialData = None
			self._onSpatialData = None
		else:
			self._SpatialData = handler
			self._onSpatialData = self._SpatialDataFactory(self._localSpatialDataEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetSpatial_setOnSpatialDataHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onSpatialData, None)
		except RuntimeError:
			self._SpatialData = None
			self._onSpatialData = None

	def getMinAcceleration(self):
		_MinAcceleration = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMinAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return list(_MinAcceleration)

	def getMaxAcceleration(self):
		_MaxAcceleration = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMaxAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return list(_MaxAcceleration)

	def setAHRSParameters(self, angularVelocityThreshold, angularVelocityDeltaThreshold, accelerationThreshold, magTime, accelTime, biasTime):
		_angularVelocityThreshold = ctypes.c_double(angularVelocityThreshold)
		_angularVelocityDeltaThreshold = ctypes.c_double(angularVelocityDeltaThreshold)
		_accelerationThreshold = ctypes.c_double(accelerationThreshold)
		_magTime = ctypes.c_double(magTime)
		_accelTime = ctypes.c_double(accelTime)
		_biasTime = ctypes.c_double(biasTime)

		__func = PhidgetSupport.getDll().PhidgetSpatial_setAHRSParameters
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _angularVelocityThreshold, _angularVelocityDeltaThreshold, _accelerationThreshold, _magTime, _accelTime, _biasTime)

		if result > 0:
			raise PhidgetException(result)


	def getAlgorithm(self):
		_Algorithm = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getAlgorithm
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Algorithm))

		if result > 0:
			raise PhidgetException(result)

		return _Algorithm.value

	def setAlgorithm(self, Algorithm):
		_Algorithm = ctypes.c_int(Algorithm)

		__func = PhidgetSupport.getDll().PhidgetSpatial_setAlgorithm
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Algorithm)

		if result > 0:
			raise PhidgetException(result)


	def getAlgorithmMagnetometerGain(self):
		_AlgorithmMagnetometerGain = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getAlgorithmMagnetometerGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_AlgorithmMagnetometerGain))

		if result > 0:
			raise PhidgetException(result)

		return _AlgorithmMagnetometerGain.value

	def setAlgorithmMagnetometerGain(self, AlgorithmMagnetometerGain):
		_AlgorithmMagnetometerGain = ctypes.c_double(AlgorithmMagnetometerGain)

		__func = PhidgetSupport.getDll().PhidgetSpatial_setAlgorithmMagnetometerGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _AlgorithmMagnetometerGain)

		if result > 0:
			raise PhidgetException(result)


	def getMinAngularRate(self):
		_MinAngularRate = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMinAngularRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAngularRate))

		if result > 0:
			raise PhidgetException(result)

		return list(_MinAngularRate)

	def getMaxAngularRate(self):
		_MaxAngularRate = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMaxAngularRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAngularRate))

		if result > 0:
			raise PhidgetException(result)

		return list(_MaxAngularRate)

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetSpatial_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetSpatial_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getEulerAngles(self):
		_EulerAngles = SpatialEulerAngles()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getEulerAngles
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_EulerAngles))

		if result > 0:
			raise PhidgetException(result)

		return _EulerAngles.toPython()

	def getHeatingEnabled(self):
		_HeatingEnabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getHeatingEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HeatingEnabled))

		if result > 0:
			raise PhidgetException(result)

		return bool(_HeatingEnabled.value)

	def setHeatingEnabled(self, HeatingEnabled):
		_HeatingEnabled = ctypes.c_int(HeatingEnabled)

		__func = PhidgetSupport.getDll().PhidgetSpatial_setHeatingEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _HeatingEnabled)

		if result > 0:
			raise PhidgetException(result)


	def getMinMagneticField(self):
		_MinMagneticField = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMinMagneticField
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinMagneticField))

		if result > 0:
			raise PhidgetException(result)

		return list(_MinMagneticField)

	def getMaxMagneticField(self):
		_MaxMagneticField = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getMaxMagneticField
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxMagneticField))

		if result > 0:
			raise PhidgetException(result)

		return list(_MaxMagneticField)

	def setMagnetometerCorrectionParameters(self, magneticField, offset0, offset1, offset2, gain0, gain1, gain2, T0, T1, T2, T3, T4, T5):
		_magneticField = ctypes.c_double(magneticField)
		_offset0 = ctypes.c_double(offset0)
		_offset1 = ctypes.c_double(offset1)
		_offset2 = ctypes.c_double(offset2)
		_gain0 = ctypes.c_double(gain0)
		_gain1 = ctypes.c_double(gain1)
		_gain2 = ctypes.c_double(gain2)
		_T0 = ctypes.c_double(T0)
		_T1 = ctypes.c_double(T1)
		_T2 = ctypes.c_double(T2)
		_T3 = ctypes.c_double(T3)
		_T4 = ctypes.c_double(T4)
		_T5 = ctypes.c_double(T5)

		__func = PhidgetSupport.getDll().PhidgetSpatial_setMagnetometerCorrectionParameters
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _magneticField, _offset0, _offset1, _offset2, _gain0, _gain1, _gain2, _T0, _T1, _T2, _T3, _T4, _T5)

		if result > 0:
			raise PhidgetException(result)


	def getQuaternion(self):
		_Quaternion = SpatialQuaternion()

		__func = PhidgetSupport.getDll().PhidgetSpatial_getQuaternion
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Quaternion))

		if result > 0:
			raise PhidgetException(result)

		return _Quaternion.toPython()

	def resetMagnetometerCorrectionParameters(self):
		__func = PhidgetSupport.getDll().PhidgetSpatial_resetMagnetometerCorrectionParameters
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def saveMagnetometerCorrectionParameters(self):
		__func = PhidgetSupport.getDll().PhidgetSpatial_saveMagnetometerCorrectionParameters
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def zeroAlgorithm(self):
		__func = PhidgetSupport.getDll().PhidgetSpatial_zeroAlgorithm
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def zeroGyro(self):
		__func = PhidgetSupport.getDll().PhidgetSpatial_zeroGyro
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
class DriveMode:
	# Configures the motor for coasting deceleration
	DRIVE_MODE_COAST = 1
	# Configures the motor for forced deceleration
	DRIVE_MODE_FORCED = 2

	@classmethod
	def getName(self, val):
		if val == self.DRIVE_MODE_COAST:
			return "DRIVE_MODE_COAST"
		if val == self.DRIVE_MODE_FORCED:
			return "DRIVE_MODE_FORCED"
		return "<invalid enumeration value>"



import sys
import ctypes
class ErrorEventCode:
	# Client and Server protocol versions don't match. Ensure that both sides are using the same release of phidget22.
	EEPHIDGET_BADVERSION = 1
	# Check that the Phidget is not already open in another program, such as the Phidget Control Panel, or another program you are developing.
	EEPHIDGET_BUSY = 2
	# This could be a network communication issue, an authentication issue (if server password is enabled), or a Device access / hardware issue.
	EEPHIDGET_NETWORK = 3
	# An error occured dispatching a command or event.
	EEPHIDGET_DISPATCH = 4
	# A general failure occured - see description for details.
	EEPHIDGET_FAILURE = 5
	# An error state has cleared.
	EEPHIDGET_OK = 4096
	# A sampling overrun happened in firmware.
	EEPHIDGET_OVERRUN = 4098
	# One or more packets were lost.
	EEPHIDGET_PACKETLOST = 4099
	# Variable has wrapped around.
	EEPHIDGET_WRAP = 4100
	# Over-temperature condition detected.
	EEPHIDGET_OVERTEMP = 4101
	# Over-current condition detected.
	EEPHIDGET_OVERCURRENT = 4102
	# Out of range condition detected.
	EEPHIDGET_OUTOFRANGE = 4103
	# Power supply problem detected.
	EEPHIDGET_BADPOWER = 4104
	# Saturation condition detected.
	EEPHIDGET_SATURATION = 4105
	# Over-voltage condition detected.
	EEPHIDGET_OVERVOLTAGE = 4107
	# Failsafe condition detected.
	EEPHIDGET_FAILSAFE = 4108
	# Voltage error detected.
	EEPHIDGET_VOLTAGEERROR = 4109
	# Energy dump condition detected.
	EEPHIDGET_ENERGYDUMP = 4110
	# Motor stall detected.
	EEPHIDGET_MOTORSTALL = 4111
	# Invalid state detected.
	EEPHIDGET_INVALIDSTATE = 4112
	# Bad connection detected.
	EEPHIDGET_BADCONNECTION = 4113
	# Measurement is above the valid range.
	EEPHIDGET_OUTOFRANGEHIGH = 4114
	# Measurement is below the valid range.
	EEPHIDGET_OUTOFRANGELOW = 4115
	# Fault condition detected.
	EEPHIDGET_FAULT = 4116
	# External stop condition detected.
	EEPHIDGET_ESTOP = 4117

	@classmethod
	def getName(self, val):
		if val == self.EEPHIDGET_BADVERSION:
			return "EEPHIDGET_BADVERSION"
		if val == self.EEPHIDGET_BUSY:
			return "EEPHIDGET_BUSY"
		if val == self.EEPHIDGET_NETWORK:
			return "EEPHIDGET_NETWORK"
		if val == self.EEPHIDGET_DISPATCH:
			return "EEPHIDGET_DISPATCH"
		if val == self.EEPHIDGET_FAILURE:
			return "EEPHIDGET_FAILURE"
		if val == self.EEPHIDGET_OK:
			return "EEPHIDGET_OK"
		if val == self.EEPHIDGET_OVERRUN:
			return "EEPHIDGET_OVERRUN"
		if val == self.EEPHIDGET_PACKETLOST:
			return "EEPHIDGET_PACKETLOST"
		if val == self.EEPHIDGET_WRAP:
			return "EEPHIDGET_WRAP"
		if val == self.EEPHIDGET_OVERTEMP:
			return "EEPHIDGET_OVERTEMP"
		if val == self.EEPHIDGET_OVERCURRENT:
			return "EEPHIDGET_OVERCURRENT"
		if val == self.EEPHIDGET_OUTOFRANGE:
			return "EEPHIDGET_OUTOFRANGE"
		if val == self.EEPHIDGET_BADPOWER:
			return "EEPHIDGET_BADPOWER"
		if val == self.EEPHIDGET_SATURATION:
			return "EEPHIDGET_SATURATION"
		if val == self.EEPHIDGET_OVERVOLTAGE:
			return "EEPHIDGET_OVERVOLTAGE"
		if val == self.EEPHIDGET_FAILSAFE:
			return "EEPHIDGET_FAILSAFE"
		if val == self.EEPHIDGET_VOLTAGEERROR:
			return "EEPHIDGET_VOLTAGEERROR"
		if val == self.EEPHIDGET_ENERGYDUMP:
			return "EEPHIDGET_ENERGYDUMP"
		if val == self.EEPHIDGET_MOTORSTALL:
			return "EEPHIDGET_MOTORSTALL"
		if val == self.EEPHIDGET_INVALIDSTATE:
			return "EEPHIDGET_INVALIDSTATE"
		if val == self.EEPHIDGET_BADCONNECTION:
			return "EEPHIDGET_BADCONNECTION"
		if val == self.EEPHIDGET_OUTOFRANGEHIGH:
			return "EEPHIDGET_OUTOFRANGEHIGH"
		if val == self.EEPHIDGET_OUTOFRANGELOW:
			return "EEPHIDGET_OUTOFRANGELOW"
		if val == self.EEPHIDGET_FAULT:
			return "EEPHIDGET_FAULT"
		if val == self.EEPHIDGET_ESTOP:
			return "EEPHIDGET_ESTOP"
		return "<invalid enumeration value>"



import sys
import ctypes
class PhidgetServerType:
	# Phidget22 Server<br/>Server discovery with this server type allows discovery of servers hosting Phidget devices. Enabling server discovery with this server type allows automated connection to these servers, and the Phidgets connected to them. Enabling server discovery with this server type will also enable ServerAdded and ServerRemoved events for this server type.
	PHIDGETSERVER_DEVICEREMOTE = 3
	# Phidget22 Web server<br/>Server discovery with this server type detects the presence of Phidget web servers used to communicate with in-browser JavaScript. Enabling server discovery with this server type will enable ServerAdded and ServerRemoved events for this server type.
	PHIDGETSERVER_WWWREMOTE = 6
	# Phidget SBC<br/>Server discovery with this server type detects the presence of Network Phidgets (SBC3003, HUB5000, etc.). Enabling server discovery with this server type will enable ServerAdded and ServerRemoved events for this server type.
	PHIDGETSERVER_SBC = 7

	@classmethod
	def getName(self, val):
		if val == self.PHIDGETSERVER_DEVICEREMOTE:
			return "PHIDGETSERVER_DEVICEREMOTE"
		if val == self.PHIDGETSERVER_WWWREMOTE:
			return "PHIDGETSERVER_WWWREMOTE"
		if val == self.PHIDGETSERVER_SBC:
			return "PHIDGETSERVER_SBC"
		return "<invalid enumeration value>"



import sys
import ctypes
class DeviceID:
	# Unknown device
	PHIDID_UNKNOWN = 125
	# Hub Port in Digital Input mode
	PHIDID_DIGITALINPUT_PORT = 95
	# Hub Port in Digital Output mode
	PHIDID_DIGITALOUTPUT_PORT = 96
	# Hub Port in Voltage Input mode
	PHIDID_VOLTAGEINPUT_PORT = 97
	# Hub Port in Voltage Ratio Input mode
	PHIDID_VOLTAGERATIOINPUT_PORT = 98
	# Dictionary
	PHIDID_DICTIONARY = 111
	# PhidgetServo 1-Motor (1000)
	PHIDID_1000 = 2
	# PhidgetServo 4-Motor (1001)
	PHIDID_1001 = 3
	# PhidgetAnalog 4-Output (1002)
	PHIDID_1002 = 4
	# PhidgetAccelerometer 2-Axis (1008)
	PHIDID_1008 = 5
	# PhidgetInterfaceKit 8/8/8 (1010, 1013, 1018, 1019)
	PHIDID_1010_1013_1018_1019 = 6
	# PhidgetInterfaceKit 2/2/2 (1011)
	PHIDID_1011 = 7
	# PhidgetInterfaceKit 0/16/16 (1012)
	PHIDID_1012 = 8
	# PhidgetInterfaceKit 0/0/4 (1014)
	PHIDID_1014 = 9
	# PhidgetLinearTouch (1015)
	PHIDID_1015 = 10
	# PhidgetCircularTouch (1016)
	PHIDID_1016 = 11
	# PhidgetInterfaceKit 0/0/8 (1017)
	PHIDID_1017 = 12
	# PhidgetRFID (1023)
	PHIDID_1023 = 13
	# PhidgetRFID Read-Write (1024)
	PHIDID_1024 = 14
	# PhidgetLED-64 (1030)
	PHIDID_1030 = 15
	# PhidgetLED-64 Advanced (1031)
	PHIDID_1031 = 16
	# PhidgetLED-64 Advanced (1032)
	PHIDID_1032 = 17
	# PhidgetGPS (1040)
	PHIDID_1040 = 18
	# PhidgetSpatial 0/0/3 Basic (1041)
	PHIDID_1041 = 19
	# PhidgetSpatial 3/3/3 Basic (1042)
	PHIDID_1042 = 20
	# PhidgetSpatial Precision 0/0/3 High Resolution (1043)
	PHIDID_1043 = 21
	# PhidgetSpatial Precision 3/3/3 High Resolution (1044)
	PHIDID_1044 = 22
	# PhidgetTemperatureSensor IR (1045)
	PHIDID_1045 = 23
	# PhidgetBridge 4-Input (1046)
	PHIDID_1046 = 24
	# PhidgetEncoder HighSpeed 4-Input (1047)
	PHIDID_1047 = 25
	# PhidgetTemperatureSensor 4-input (1048)
	PHIDID_1048 = 26
	# PhidgetSpatial 0/0/3 (1049)
	PHIDID_1049 = 27
	# PhidgetTemperatureSensor 1-Input (1051)
	PHIDID_1051 = 28
	# PhidgetEncoder Mechanical (1052)
	PHIDID_1052 = 29
	# PhidgetAccelerometer 2-Axis (1053)
	PHIDID_1053 = 30
	# PhidgetFrequencyCounter (1054)
	PHIDID_1054 = 31
	# PhidgetIR (1055)
	PHIDID_1055 = 32
	# PhidgetSpatial 3/3/3 (1056)
	PHIDID_1056 = 33
	# PhidgetEncoder HighSpeed (1057)
	PHIDID_1057 = 34
	# PhidgetPHSensor (1058)
	PHIDID_1058 = 35
	# PhidgetAccelerometer 3-Axis (1059)
	PHIDID_1059 = 36
	# PhidgetMotorControl LV (1060)
	PHIDID_1060 = 37
	# PhidgetAdvancedServo 8-Motor (1061)
	PHIDID_1061 = 38
	# PhidgetStepper Unipolar 4-Motor (1062)
	PHIDID_1062 = 39
	# PhidgetStepper Bipolar 1-Motor (1063)
	PHIDID_1063 = 40
	# PhidgetMotorControl HC (1064)
	PHIDID_1064 = 41
	# PhidgetMotorControl 1-Motor (1065)
	PHIDID_1065 = 42
	# PhidgetAdvancedServo 1-Motor (1066)
	PHIDID_1066 = 43
	# PhidgetStepper Bipolar HC (1067)
	PHIDID_1067 = 44
	# PhidgetTextLCD 20x2 with PhidgetInterfaceKit 8/8/8 (1202, 1203)
	PHIDID_1202_1203 = 45
	# PhidgetTextLCD Adapter (1204)
	PHIDID_1204 = 46
	# PhidgetTextLCD 20x2 (1215, 1216, 1217, 1218)
	PHIDID_1215__1218 = 47
	# PhidgetTextLCD 20x2 with PhidgetInterfaceKit 0/8/8 (1219, 1220, 1221, 1222)
	PHIDID_1219__1222 = 48
	# pH Adapter
	PHIDID_ADP1000 = 49
	# Analog Input Module x8
	PHIDID_DAQ1000 = 51
	# Digital Input 4
	PHIDID_DAQ1200 = 52
	# Digital Input 4 Isolated
	PHIDID_DAQ1300 = 53
	# Digital Input 16
	PHIDID_DAQ1301 = 54
	# Versatile Input
	PHIDID_DAQ1400 = 55
	# Bridge
	PHIDID_DAQ1500 = 56
	# DC Motor Controller with PID
	PHIDID_DCC1000 = 57
	# Small DC Motor Controller
	PHIDID_DCC1001 = 110
	# 4A Small DC Motor Controller
	PHIDID_DCC1002 = 117
	# 2 Channel DC Motor Controller
	PHIDID_DCC1003 = 120
	# BLDC Motor Controller
	PHIDID_DCC1100 = 108
	# 200mm Distance Sensor
	PHIDID_DST1000 = 58
	# 650mm distance sensor
	PHIDID_DST1001 = 121
	# 1200mm distance sensor
	PHIDID_DST1002 = 126
	# Sonar Distance Sensor
	PHIDID_DST1200 = 59
	# Encoder
	PHIDID_ENC1000 = 60
	# Encoder
	PHIDID_ENC1001 = 155
	# Capacitive Touch Sensor
	PHIDID_HIN1000 = 61
	# Capacitive Scroll
	PHIDID_HIN1001 = 62
	# Joystick
	PHIDID_HIN1100 = 63
	# Dial Encoder
	PHIDID_HIN1101 = 109
	# Phidget USB VINT Hub with 6 ports
	PHIDID_HUB0000 = 64
	# Phidget USB VINT Hub with 6 ports
	PHIDID_HUB0001 = 142
	# Phidget USB VINT Hub with 6 ports
	PHIDID_HUB0002 = 147
	# Phidget SPI VINT Hub with 6 ports
	PHIDID_HUB0004 = 67
	# Phidget USB VINT Hub with 1 port
	PHIDID_HUB0007 = 148
	# Phidget Network Hub with 6 ports
	PHIDID_HUB5000 = 123
	# Humidity Sensor
	PHIDID_HUM1000 = 69
	# Humidity Sensor
	PHIDID_HUM1001 = 127
	# VINT Moisture Sensor
	PHIDID_HUM1100 = 136
	# LCD
	PHIDID_LCD1100 = 70
	# LED Driver 32
	PHIDID_LED1000 = 71
	# Light Sensor
	PHIDID_LUX1000 = 72
	# Phidget Accelerometer
	PHIDID_MOT0100 = 146
	# PhidgetSpatial Precision 3/3/3
	PHIDID_MOT0109 = 140
	# PhidgetSpatial Precision 3/3/3
	PHIDID_MOT0110 = 141
	# Accelerometer 0/0/3
	PHIDID_MOT1100 = 73
	# Spatial 3/3/3
	PHIDID_MOT1101 = 74
	# VINT Spatial Phidget AHRS
	PHIDID_MOT1102 = 137
	# Analog Output 0-5V
	PHIDID_OUT1000 = 75
	# Analog Output (+/-)10V
	PHIDID_OUT1001 = 76
	# Analog Output (+/-)10V - 16 bit
	PHIDID_OUT1002 = 77
	# Digital Output 4
	PHIDID_OUT1100 = 78
	# Barometer
	PHIDID_PRE1000 = 79
	# PhidgetAdvancedServo 8-Motor
	PHIDID_RCC0004 = 124
	# 8-Servo Controller
	PHIDID_RCC1000 = 80
	# Power Relay 4
	PHIDID_REL1000 = 81
	# Digital Output 4 Isolated
	PHIDID_REL1100 = 82
	# Digital Output 16 Isolated
	PHIDID_REL1101 = 83
	# Power Supply Protector
	PHIDID_SAF1000 = 84
	# Sound Pressure Level Sensor
	PHIDID_SND1000 = 85
	# Bipolar Stepper Motor Controller
	PHIDID_STC1000 = 86
	# Bipolar Stepper Motor SmallController
	PHIDID_STC1001 = 115
	# 8A Bipolar Stepper Motor Controller
	PHIDID_STC1002 = 118
	# 4A Bipolar Stepper Motor SmallController
	PHIDID_STC1003 = 119
	# 4A Bipolar Stepper Motor SmallController
	PHIDID_STC1005 = 149
	# Integrated Temperature Sensor
	PHIDID_TMP1000 = 87
	# Thermocouple 1
	PHIDID_TMP1100 = 88
	# Thermocouple 4
	PHIDID_TMP1101 = 89
	# RTD
	PHIDID_TMP1200 = 90
	# Voltage Sensor High Precision
	PHIDID_VCP1000 = 92
	# Voltage Sensor Large
	PHIDID_VCP1001 = 93
	# Voltage Sensor Small
	PHIDID_VCP1002 = 94
	# 30A Current Sensor
	PHIDID_VCP1100 = 105

	@classmethod
	def getName(self, val):
		if val == self.PHIDID_UNKNOWN:
			return "PHIDID_UNKNOWN"
		if val == self.PHIDID_DIGITALINPUT_PORT:
			return "PHIDID_DIGITALINPUT_PORT"
		if val == self.PHIDID_DIGITALOUTPUT_PORT:
			return "PHIDID_DIGITALOUTPUT_PORT"
		if val == self.PHIDID_VOLTAGEINPUT_PORT:
			return "PHIDID_VOLTAGEINPUT_PORT"
		if val == self.PHIDID_VOLTAGERATIOINPUT_PORT:
			return "PHIDID_VOLTAGERATIOINPUT_PORT"
		if val == self.PHIDID_DICTIONARY:
			return "PHIDID_DICTIONARY"
		if val == self.PHIDID_1000:
			return "PHIDID_1000"
		if val == self.PHIDID_1001:
			return "PHIDID_1001"
		if val == self.PHIDID_1002:
			return "PHIDID_1002"
		if val == self.PHIDID_1008:
			return "PHIDID_1008"
		if val == self.PHIDID_1010_1013_1018_1019:
			return "PHIDID_1010_1013_1018_1019"
		if val == self.PHIDID_1011:
			return "PHIDID_1011"
		if val == self.PHIDID_1012:
			return "PHIDID_1012"
		if val == self.PHIDID_1014:
			return "PHIDID_1014"
		if val == self.PHIDID_1015:
			return "PHIDID_1015"
		if val == self.PHIDID_1016:
			return "PHIDID_1016"
		if val == self.PHIDID_1017:
			return "PHIDID_1017"
		if val == self.PHIDID_1023:
			return "PHIDID_1023"
		if val == self.PHIDID_1024:
			return "PHIDID_1024"
		if val == self.PHIDID_1030:
			return "PHIDID_1030"
		if val == self.PHIDID_1031:
			return "PHIDID_1031"
		if val == self.PHIDID_1032:
			return "PHIDID_1032"
		if val == self.PHIDID_1040:
			return "PHIDID_1040"
		if val == self.PHIDID_1041:
			return "PHIDID_1041"
		if val == self.PHIDID_1042:
			return "PHIDID_1042"
		if val == self.PHIDID_1043:
			return "PHIDID_1043"
		if val == self.PHIDID_1044:
			return "PHIDID_1044"
		if val == self.PHIDID_1045:
			return "PHIDID_1045"
		if val == self.PHIDID_1046:
			return "PHIDID_1046"
		if val == self.PHIDID_1047:
			return "PHIDID_1047"
		if val == self.PHIDID_1048:
			return "PHIDID_1048"
		if val == self.PHIDID_1049:
			return "PHIDID_1049"
		if val == self.PHIDID_1051:
			return "PHIDID_1051"
		if val == self.PHIDID_1052:
			return "PHIDID_1052"
		if val == self.PHIDID_1053:
			return "PHIDID_1053"
		if val == self.PHIDID_1054:
			return "PHIDID_1054"
		if val == self.PHIDID_1055:
			return "PHIDID_1055"
		if val == self.PHIDID_1056:
			return "PHIDID_1056"
		if val == self.PHIDID_1057:
			return "PHIDID_1057"
		if val == self.PHIDID_1058:
			return "PHIDID_1058"
		if val == self.PHIDID_1059:
			return "PHIDID_1059"
		if val == self.PHIDID_1060:
			return "PHIDID_1060"
		if val == self.PHIDID_1061:
			return "PHIDID_1061"
		if val == self.PHIDID_1062:
			return "PHIDID_1062"
		if val == self.PHIDID_1063:
			return "PHIDID_1063"
		if val == self.PHIDID_1064:
			return "PHIDID_1064"
		if val == self.PHIDID_1065:
			return "PHIDID_1065"
		if val == self.PHIDID_1066:
			return "PHIDID_1066"
		if val == self.PHIDID_1067:
			return "PHIDID_1067"
		if val == self.PHIDID_1202_1203:
			return "PHIDID_1202_1203"
		if val == self.PHIDID_1204:
			return "PHIDID_1204"
		if val == self.PHIDID_1215__1218:
			return "PHIDID_1215__1218"
		if val == self.PHIDID_1219__1222:
			return "PHIDID_1219__1222"
		if val == self.PHIDID_ADP1000:
			return "PHIDID_ADP1000"
		if val == self.PHIDID_DAQ1000:
			return "PHIDID_DAQ1000"
		if val == self.PHIDID_DAQ1200:
			return "PHIDID_DAQ1200"
		if val == self.PHIDID_DAQ1300:
			return "PHIDID_DAQ1300"
		if val == self.PHIDID_DAQ1301:
			return "PHIDID_DAQ1301"
		if val == self.PHIDID_DAQ1400:
			return "PHIDID_DAQ1400"
		if val == self.PHIDID_DAQ1500:
			return "PHIDID_DAQ1500"
		if val == self.PHIDID_DCC1000:
			return "PHIDID_DCC1000"
		if val == self.PHIDID_DCC1001:
			return "PHIDID_DCC1001"
		if val == self.PHIDID_DCC1002:
			return "PHIDID_DCC1002"
		if val == self.PHIDID_DCC1003:
			return "PHIDID_DCC1003"
		if val == self.PHIDID_DCC1100:
			return "PHIDID_DCC1100"
		if val == self.PHIDID_DST1000:
			return "PHIDID_DST1000"
		if val == self.PHIDID_DST1001:
			return "PHIDID_DST1001"
		if val == self.PHIDID_DST1002:
			return "PHIDID_DST1002"
		if val == self.PHIDID_DST1200:
			return "PHIDID_DST1200"
		if val == self.PHIDID_ENC1000:
			return "PHIDID_ENC1000"
		if val == self.PHIDID_ENC1001:
			return "PHIDID_ENC1001"
		if val == self.PHIDID_HIN1000:
			return "PHIDID_HIN1000"
		if val == self.PHIDID_HIN1001:
			return "PHIDID_HIN1001"
		if val == self.PHIDID_HIN1100:
			return "PHIDID_HIN1100"
		if val == self.PHIDID_HIN1101:
			return "PHIDID_HIN1101"
		if val == self.PHIDID_HUB0000:
			return "PHIDID_HUB0000"
		if val == self.PHIDID_HUB0001:
			return "PHIDID_HUB0001"
		if val == self.PHIDID_HUB0002:
			return "PHIDID_HUB0002"
		if val == self.PHIDID_HUB0004:
			return "PHIDID_HUB0004"
		if val == self.PHIDID_HUB0007:
			return "PHIDID_HUB0007"
		if val == self.PHIDID_HUB5000:
			return "PHIDID_HUB5000"
		if val == self.PHIDID_HUM1000:
			return "PHIDID_HUM1000"
		if val == self.PHIDID_HUM1001:
			return "PHIDID_HUM1001"
		if val == self.PHIDID_HUM1100:
			return "PHIDID_HUM1100"
		if val == self.PHIDID_LCD1100:
			return "PHIDID_LCD1100"
		if val == self.PHIDID_LED1000:
			return "PHIDID_LED1000"
		if val == self.PHIDID_LUX1000:
			return "PHIDID_LUX1000"
		if val == self.PHIDID_MOT0100:
			return "PHIDID_MOT0100"
		if val == self.PHIDID_MOT0109:
			return "PHIDID_MOT0109"
		if val == self.PHIDID_MOT0110:
			return "PHIDID_MOT0110"
		if val == self.PHIDID_MOT1100:
			return "PHIDID_MOT1100"
		if val == self.PHIDID_MOT1101:
			return "PHIDID_MOT1101"
		if val == self.PHIDID_MOT1102:
			return "PHIDID_MOT1102"
		if val == self.PHIDID_OUT1000:
			return "PHIDID_OUT1000"
		if val == self.PHIDID_OUT1001:
			return "PHIDID_OUT1001"
		if val == self.PHIDID_OUT1002:
			return "PHIDID_OUT1002"
		if val == self.PHIDID_OUT1100:
			return "PHIDID_OUT1100"
		if val == self.PHIDID_PRE1000:
			return "PHIDID_PRE1000"
		if val == self.PHIDID_RCC0004:
			return "PHIDID_RCC0004"
		if val == self.PHIDID_RCC1000:
			return "PHIDID_RCC1000"
		if val == self.PHIDID_REL1000:
			return "PHIDID_REL1000"
		if val == self.PHIDID_REL1100:
			return "PHIDID_REL1100"
		if val == self.PHIDID_REL1101:
			return "PHIDID_REL1101"
		if val == self.PHIDID_SAF1000:
			return "PHIDID_SAF1000"
		if val == self.PHIDID_SND1000:
			return "PHIDID_SND1000"
		if val == self.PHIDID_STC1000:
			return "PHIDID_STC1000"
		if val == self.PHIDID_STC1001:
			return "PHIDID_STC1001"
		if val == self.PHIDID_STC1002:
			return "PHIDID_STC1002"
		if val == self.PHIDID_STC1003:
			return "PHIDID_STC1003"
		if val == self.PHIDID_STC1005:
			return "PHIDID_STC1005"
		if val == self.PHIDID_TMP1000:
			return "PHIDID_TMP1000"
		if val == self.PHIDID_TMP1100:
			return "PHIDID_TMP1100"
		if val == self.PHIDID_TMP1101:
			return "PHIDID_TMP1101"
		if val == self.PHIDID_TMP1200:
			return "PHIDID_TMP1200"
		if val == self.PHIDID_VCP1000:
			return "PHIDID_VCP1000"
		if val == self.PHIDID_VCP1001:
			return "PHIDID_VCP1001"
		if val == self.PHIDID_VCP1002:
			return "PHIDID_VCP1002"
		if val == self.PHIDID_VCP1100:
			return "PHIDID_VCP1100"
		return "<invalid enumeration value>"



import sys
import ctypes
class PositionType:
	# Configures the controller to use the encoder as a position source
	POSITION_TYPE_ENCODER = 1
	# Configures the controller to use the hall-effect sensor as a position source
	POSITION_TYPE_HALL_SENSOR = 2

	@classmethod
	def getName(self, val):
		if val == self.POSITION_TYPE_ENCODER:
			return "POSITION_TYPE_ENCODER"
		if val == self.POSITION_TYPE_HALL_SENSOR:
			return "POSITION_TYPE_HALL_SENSOR"
		return "<invalid enumeration value>"



import sys
import ctypes
class LCDFont:
	# User-defined font #1
	FONT_User1 = 1
	# User-defined font #2
	FONT_User2 = 2
	# 6px by 10px font
	FONT_6x10 = 3
	# 5px by 8px font
	FONT_5x8 = 4
	# 6px by 12px font
	FONT_6x12 = 5

	@classmethod
	def getName(self, val):
		if val == self.FONT_User1:
			return "FONT_User1"
		if val == self.FONT_User2:
			return "FONT_User2"
		if val == self.FONT_6x10:
			return "FONT_6x10"
		if val == self.FONT_5x8:
			return "FONT_5x8"
		if val == self.FONT_6x12:
			return "FONT_6x12"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetServerType import PhidgetServerType
from Phidget22.PhidgetServer import PhidgetServer
from Phidget22.PhidgetServerType import PhidgetServerType
from Phidget22.PhidgetException import PhidgetException

class Net:

	def __init__(self):
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._ServerAddedFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.POINTER(PhidgetServer), ctypes.c_void_p)
		else:
			self._ServerAddedFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.POINTER(PhidgetServer), ctypes.c_void_p)
		self._ServerAdded = None
		self._onServerAdded = None

		if sys.platform == 'win32':
			self._ServerRemovedFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.POINTER(PhidgetServer))
		else:
			self._ServerRemovedFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.POINTER(PhidgetServer))
		self._ServerRemoved = None
		self._onServerRemoved = None


	def __del__(self):
			pass

	def _localServerAddedEvent(self, userPtr, server, kv):
		if self._ServerAdded == None:
			return
		if server != None:
			server = server.contents
			server.toPython()
		self._ServerAdded(self, server, kv)

	def setOnServerAddedHandler(self, handler):
		if handler == None:
			self._ServerAdded = None
			self._onServerAdded = None
		else:
			self._ServerAdded = handler
			self._onServerAdded = self._ServerAddedFactory(self._localServerAddedEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetNet_setOnServerAddedHandler
			__func.restype = ctypes.c_int32
			res = __func(self._onServerAdded, None)
		except RuntimeError:
			self._ServerAdded = None
			self._onServerAdded = None

	def _localServerRemovedEvent(self, userPtr, server):
		if self._ServerRemoved == None:
			return
		if server != None:
			server = server.contents
			server.toPython()
		self._ServerRemoved(self, server)

	def setOnServerRemovedHandler(self, handler):
		if handler == None:
			self._ServerRemoved = None
			self._onServerRemoved = None
		else:
			self._ServerRemoved = handler
			self._onServerRemoved = self._ServerRemovedFactory(self._localServerRemovedEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetNet_setOnServerRemovedHandler
			__func.restype = ctypes.c_int32
			res = __func(self._onServerRemoved, None)
		except RuntimeError:
			self._ServerRemoved = None
			self._onServerRemoved = None

	@staticmethod
	def addServer(serverName, address, port, password, flags):
		_serverName = ctypes.create_string_buffer(serverName.encode('utf-8'))
		_address = ctypes.create_string_buffer(address.encode('utf-8'))
		_port = ctypes.c_int(port)
		_password = ctypes.create_string_buffer(password.encode('utf-8'))
		_flags = ctypes.c_int(flags)

		__func = PhidgetSupport.getDll().PhidgetNet_addServer
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_serverName), ctypes.byref(_address), _port, ctypes.byref(_password), _flags)

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def removeServer(serverName):
		_serverName = ctypes.create_string_buffer(serverName.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetNet_removeServer
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_serverName))

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def enableServer(serverName):
		_serverName = ctypes.create_string_buffer(serverName.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetNet_enableServer
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_serverName))

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def disableServer(serverName, flags):
		_serverName = ctypes.create_string_buffer(serverName.encode('utf-8'))
		_flags = ctypes.c_int(flags)

		__func = PhidgetSupport.getDll().PhidgetNet_disableServer
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_serverName), _flags)

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def enableServerDiscovery(serverType):
		_serverType = ctypes.c_int(serverType)

		__func = PhidgetSupport.getDll().PhidgetNet_enableServerDiscovery
		__func.restype = ctypes.c_int32
		result = __func(_serverType)

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def disableServerDiscovery(serverType):
		_serverType = ctypes.c_int(serverType)

		__func = PhidgetSupport.getDll().PhidgetNet_disableServerDiscovery
		__func.restype = ctypes.c_int32
		result = __func(_serverType)

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def setServerPassword(serverName, password):
		_serverName = ctypes.create_string_buffer(serverName.encode('utf-8'))
		_password = ctypes.create_string_buffer(password.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetNet_setServerPassword
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_serverName), ctypes.byref(_password))

		if result > 0:
			raise PhidgetException(result)


	AUTHREQUIRED = 1
